changeset 25731:64fabfc191d7

__run_test_suite__.m: Ignore legacy/ directory files during testing. * __run_test_suite__.m: Disable warning "Octave:legacy-function" while running test suite. Don't report that m-files in legacy/ directory are missing tests.
author Rik <rik@octave.org>
date Thu, 02 Aug 2018 10:14:31 -0700
parents 5bf1d8a0bcf7
children 8b0e362f2176
files scripts/testfun/__run_test_suite__.m
diffstat 1 files changed, 4 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/scripts/testfun/__run_test_suite__.m	Thu Aug 02 10:01:59 2018 -0700
+++ b/scripts/testfun/__run_test_suite__.m	Thu Aug 02 10:14:31 2018 -0700
@@ -51,6 +51,7 @@
     page_screen_output (false);
     warning ("on", "quiet");
     warning ("off", "Octave:deprecated-function");
+    warning ("off", "Octave:legacy-function");
     nfail = dp = dn = dxf = dxb = dsk = drtsk = drgrs = 0;
     try
       fid = fopen (logfile, "wt");
@@ -116,10 +117,10 @@
         puts ("indicating which dependencies were not found.\n");
       endif
 
-      ## Weed out deprecated and private functions
-      weed_idx = cellfun (@isempty, regexp (files_with_tests, '\<deprecated\>|\<private\>', 'once'));
+      ## Weed out deprecated, legacy, and private functions
+      weed_idx = cellfun (@isempty, regexp (files_with_tests, '\<deprecated\>|\<legacy\>|\<private\>', 'once'));
       files_with_tests = files_with_tests(weed_idx);
-      weed_idx = cellfun (@isempty, regexp (files_with_no_tests, '\<deprecated\>|\<private\>', 'once'));
+      weed_idx = cellfun (@isempty, regexp (files_with_no_tests, '\<deprecated\>|\<legacy\>|\<private\>', 'once'));
       files_with_no_tests = files_with_no_tests(weed_idx);
 
       report_files_with_no_tests (files_with_tests, files_with_no_tests, ".m");